# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 0
%endif

%bcond_without examples

# Versioning

%define qtmajor 6
%define qtminor 7
%define qtsubminor 2
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtscxml-everywhere-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtscxml             %mklibname qt%{qtmajor}scxml %{qtmajor}
%define libqtscxml_d           %mklibname qt%{qtmajor}scxml -d

%define libqtscxmlqml          %mklibname qt%{qtmajor}scxmlqml %{qtmajor}
%define libqtscxmlqml_d        %mklibname qt%{qtmajor}scxmlqml -d

%define libqtstatemachine      %mklibname qt%{qtmajor}statemachine %{qtmajor}
%define libqtstatemachine_d    %mklibname qt%{qtmajor}statemachine -d

%define libqtstatemachineqml   %mklibname qt%{qtmajor}statemachineqml %{qtmajor}
%define libqtstatemachineqml_d %mklibname qt%{qtmajor}statemachineqml -d

Name:           qtscxml6
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} ScXml component
# See LGPL_EXCEPTIONS.txt, LICENSE.GPL3, respectively, for exception details
License:        LGPLv2 with exceptions or GPLv3 with exceptions
Group:          Development/KDE and Qt
URL:            https://www.qt.io
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
## Upstream patches:
#
## Mageia patches
Patch1001:      qtscxml-qscxmlc-intall-location.patch

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  qtbase6-qtpaths

BuildRequires:  qtbase6-devel >= %{version}
BuildRequires:  cmake(Qt6Qml) >= %{version}
BuildRequires:  cmake(Qt6QmlIntegration) >= %{version}
BuildRequires:  cmake(Qt6Quick) >= %{version}
BuildRequires:  cmake(Qt6QuickTest)

Provides:       qt%{qtmajor}-qtscxml = %{version}-%{release}

%description
The Qt SCXML module provides functionality to create state machines from
SCXML files.

This includes both dynamically creating state machines (loading the SCXML
file and instantiating states and transitions) and generating a C++ file
that has a class implementing the state machine. It also contains
functionality to support data models and executable content.

%files
%{_qt6_bindir}/qscxmlc
%{_qt6_qmldir}/QtScxml/
%{_qt6_qmldir}/QtQml/StateMachine/
%{_qt6_plugindir}/scxmldatamodel/

#------------------------------------------------------------------------------

%if %{build_docs}
%package doc
Summary:        QtScXml%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools6
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools6-assistant
Recommends:     qttools6-assistant

%description doc
Documentation for APIs and tools in QtScXml%{qtmajor} package for
use with Qt Assistant.

%files doc
%{_qt6_docdir}/qtscxml.qch
%{_qt6_docdir}/qtscxml/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtscxml}
Summary:        Qt%{qtmajor} ScXml Library
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n %{libqtscxml}
Qt%{qtmajor} ScXml Component Library.

%files -n %{libqtscxml}
%{_qt6_libdir}/libQt6Scxml.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtscxml_d}
Summary:        Devel files needed to build apps based on QtScXml
Group:          Development/KDE and Qt
Requires:       %{name} = %{version}
Requires:       %{libqtscxml} = %{version}
Provides:       libqtscxml6-devel = %{version}
Provides:       libqt6scxml-devel = %{version}
Provides:       qtscxml6-devel = %{version}
Provides:       qt6scxml-devel = %{version}
Provides:       qt%{qtmajor}-qtscxml-devel = %{version}-%{release}

%description -n %{libqtscxml_d}
Devel files needed to build apps based on QtScXml.

%files -n %{libqtscxml_d}
%{_qt6_includedir}/QtScxml/
%{_qt6_libdir}/libQt6Scxml.so
%{_qt6_libdir}/cmake/Qt6Scxml/
%{_qt6_libdir}/pkgconfig/Qt6Scxml.pc
%{_qt6_libdir}/libQt6Scxml.prl
%{_qt6_libdir}/qt6/metatypes/qt6scxml_*_metatypes.json
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_scxml.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_scxml_private.pri
%{_qt6_archdatadir}/mkspecs/features/qscxmlc.prf
%{_qt6_libdir}/qt6/modules/Scxml.json
%if %{with examples}
%{_qt6_examplesdir}/scxml/
%endif
#
%{_qt6_libdir}/cmake/Qt6ScxmlTools/
%{_qt6_libdir}/cmake/Qt6BuildInternals/StandaloneTests/QtScxmlTestsConfig.cmake
%{_qt6_libdir}/cmake/Qt6Qml/QmlPlugins/Qt6declarative_scxml*.cmake

#------------------------------------------------------------------------------

%package -n     %{libqtscxmlqml}
Summary:        Qt%{qtmajor} ScXml Qml Library
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n %{libqtscxmlqml}
Qt%{qtmajor} ScXml Qml Component Library.

%files -n %{libqtscxmlqml}
%{_qt6_libdir}/libQt6ScxmlQml.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtscxmlqml_d}
Summary:        Devel files needed to build apps based on QtScXmlQml
Group:          Development/KDE and Qt
Requires:       %{name} = %{version}
Requires:       %{libqtscxmlqml} = %{version}
Provides:       libqtscxmlqml6-devel = %{version}
Provides:       libqt6scxmlqml-devel = %{version}
Provides:       qtscxmlqml6-devel = %{version}
Provides:       qt6scxmlqml-devel = %{version}

%description -n %{libqtscxmlqml_d}
Devel files needed to build apps based on QtScXmlQml.

%files -n %{libqtscxmlqml_d}
%{_qt6_includedir}/QtScxmlQml/
%{_qt6_libdir}/libQt6ScxmlQml.so
%{_qt6_libdir}/cmake/Qt6ScxmlQml/
%{_qt6_libdir}/libQt6ScxmlQml.prl
%{_qt6_libdir}/qt6/metatypes/qt6scxmlqml_*_metatypes.json
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_scxmlqml.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_scxmlqml_private.pri
%{_qt6_libdir}/qt6/modules/ScxmlQml.json
%{_qt6_libdir}/pkgconfig/Qt6ScxmlQml.pc

#------------------------------------------------------------------------------

%package -n     %{libqtstatemachine}
Summary:        Qt%{qtmajor} State Machine Library
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n %{libqtstatemachine}
Qt%{qtmajor} State Machine Component Library.

%files -n %{libqtstatemachine}
%{_qt6_libdir}/libQt6StateMachine.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtstatemachine_d}
Summary:        Devel files needed to build apps based on QtStateMachine
Group:          Development/KDE and Qt
Requires:       %{name} = %{version}
Requires:       %{libqtstatemachine} = %{version}
Provides:       libqtstatemachine6-devel = %{version}
Provides:       libqt6statemachine-devel = %{version}
Provides:       qtstatemachine6-devel = %{version}
Provides:       qt6statemachine-devel = %{version}

%description -n %{libqtstatemachine_d}
Devel files needed to build apps based on QtStateMachine.

%files -n %{libqtstatemachine_d}
%{_qt6_includedir}/QtStateMachine/
%{_qt6_libdir}/libQt6StateMachine.so
%{_qt6_libdir}/cmake/Qt6StateMachine/
%{_qt6_libdir}/libQt6StateMachine.prl
%{_qt6_libdir}/qt6/metatypes/qt6statemachine_relwithdebinfo_metatypes.json
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_statemachine.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_statemachine_private.pri
%{_qt6_libdir}/qt6/modules/StateMachine.json
%{_qt6_libdir}/pkgconfig/Qt6StateMachine.pc

#------------------------------------------------------------------------------

%package -n     %{libqtstatemachineqml}
Summary:        Qt%{qtmajor} State Machine Qml Library
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n %{libqtstatemachineqml}
Qt%{qtmajor} State Machine Qml Component Library.

%files -n %{libqtstatemachineqml}
%{_qt6_libdir}/libQt6StateMachineQml.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtstatemachineqml_d}
Summary:        Devel files needed to build apps based on QtStateMachineQml
Group:          Development/KDE and Qt
Requires:       %{name} = %{version}
Requires:       %{libqtstatemachineqml} = %{version}
Provides:       libqtstatemachineqml6-devel = %{version}
Provides:       libqt6statemachineqml-devel = %{version}
Provides:       qtstatemachineqml6-devel = %{version}
Provides:       qt6statemachineqml-devel = %{version}

%description -n %{libqtstatemachineqml_d}
Devel files needed to build apps based on QtStateMachineQml.

%files -n %{libqtstatemachineqml_d}
%{_qt6_includedir}/QtStateMachineQml/
%{_qt6_libdir}/libQt6StateMachineQml.so
%{_qt6_libdir}/cmake/Qt6StateMachineQml/
%{_qt6_libdir}/libQt6StateMachineQml.prl
%{_qt6_libdir}/qt6/metatypes/qt6statemachineqml_*_metatypes.json
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_statemachineqml.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_statemachineqml_private.pri
%{_qt6_libdir}/qt6/modules/StateMachineQml.json
%if %{with examples}
%{_qt6_examplesdir}/statemachine/
%endif
#
%{_qt6_libdir}/cmake/Qt6Qml/QmlPlugins/Qt6qtqmlstatemachine*.cmake
%{_qt6_libdir}/pkgconfig/Qt6StateMachineQml.pc

#------------------------------------------------------------------------------

%prep
%setup -q -n qtscxml-everywhere-src-%{qtversion}
%autopatch -p1

%build
%cmake_qt6 %{!?with_examples:-DQT_BUILD_EXAMPLES:BOOL=OFF}

%cmake_build

%if %{build_docs}
%__make docs
%endif

%install
%cmake_install

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif

# .la files, die, die, die.
find %{buildroot} -name '*.la' -delete


%changelog
* Wed Jul 31 2024 daviddavid <daviddavid> 6.7.2-1.mga10
+ Revision: 2083117
- New version 6.7.2

* Tue Jun 11 2024 daviddavid <daviddavid> 6.7.1-2.mga10
+ Revision: 2072535
- rebuild for 'Qt_$MAJOR_PRIVATE_API' settings

* Wed May 22 2024 daviddavid <daviddavid> 6.7.1-1.mga10
+ Revision: 2065876
- New version 6.7.1

* Thu Feb 15 2024 daviddavid <daviddavid> 6.6.2-1.mga10
+ Revision: 2041654
- New version 6.6.2

* Thu Oct 19 2023 daviddavid <daviddavid> 6.6.0-1.mga10
+ Revision: 1999054
- New version 6.6.0

* Sun Sep 10 2023 neoclust <neoclust> 6.5.2-1.mga10
+ Revision: 1985964
- New version 6.5.2

* Tue Dec 27 2022 daviddavid <daviddavid> 6.4.1-2.mga9
+ Revision: 1927102
- build examples

* Thu Dec 15 2022 neoclust <neoclust> 6.4.1-1.mga9
+ Revision: 1923054
- New version 6.4.1

* Tue Oct 04 2022 neoclust <neoclust> 6.4.0-1.mga9
+ Revision: 1894710
- New version 6.4.0

* Sun Aug 28 2022 neoclust <neoclust> 6.3.1-1.mga9
+ Revision: 1881516
- New version 6.3.1

* Sat Jul 30 2022 wally <wally> 6.3.0-1.mga9
+ Revision: 1873596
- disable examples as they needs pkg itself to build
+ neoclust <neoclust>
- New version 6.3.0

* Tue Apr 05 2022 umeabot <umeabot> 6.2.3-2.mga9
+ Revision: 1844640
- Mageia 9 Mass Rebuild

* Sun Feb 20 2022 neoclust <neoclust> 6.2.3-1.mga9
+ Revision: 1781922
- New version 6.2.3

* Sun Nov 14 2021 neoclust <neoclust> 6.2.1-1.mga9
+ Revision: 1756254
- New version 6.2.1

* Sat Nov 13 2021 neoclust <neoclust> 6.2.0-1.mga9
+ Revision: 1756024
- New version 6.2.0

* Fri May 14 2021 daviddavid <daviddavid> 6.1.0-1.mga9
+ Revision: 1722791
- initial package qtscxml6

